/*
**  EncoderModule.h
**
**  Copyright (c) 2002, 2003
**
**  Author: Yen-Ju Chen <yjchenx@hotmail.com>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _Musicbox_MusicBox_MusicBox_H_EncoderModule
#define _Musicbox_MusicBox_MusicBox H_EncoderModule

#include <Foundation/NSObject.h>

#define EncoderPreferenceViewFrame NSMakeRect(0, 0, 300, 200)

@class SongInfo;
@class NSView;
@class NSString;

@protocol EncoderModule <NSObject>

+ (NSView *) preferenceView;

+ (NSString *) encoderName;

- (id) initWithOwner: (id) owner;

/* This is the SongInfo after encoding. 
 * Encoder should write the song/artist/album
 * into the audio file if possible.
 * The final audio file should be placed at filename.
 * The directories to the filename will be set up
 * by the MusicBox. Therefore, encoders don't need
 * to set up the directories by themselves.
 * But it's no harm to check that again.
 * Encoder can modify this SongInfo if necessary.
 * The trackNumber give the encoder which track to encoder
 */
- (void) setSongInfo: (SongInfo *) info;
- (SongInfo *) songInfo;

/* Return from 0-100 */
- (int) progress;
- (void) launch;
- (void) interrupt; /* Encoder is responsible to clean up */

@end

@interface NSObject (MusicBoxEncoder)

/* If the encoding is interrupt, didFinishEncoding should be NO.
 * Else it should be YES.
 */
- (void) encoder: (id <EncoderModule>) encoder didFinishEncoding: (BOOL) _bool;

@end

@protocol EncoderModuleView <NSObject>

- (void) loadSettings;
- (void) saveSettings;
 
@end

#endif /*  _Musicbox_MusicBox_MusicBox_H_EncoderModule */
